      function q = obqion ( elv )
%
%         ionospheric obliquity
%         based on slant path 200 to 600 km / 400 km
%
%         fitted to even polynomal in variable
%              x = (1 - elv/90_deg)**2
%
%         q = c0 + c1*x + c2*x**2 + c3*x**3
%
%
%    input:
%              elv       elevation angle in degrees
%    output:
%              obliquity value for ionosphere
%
%         -----------------------------------------
%
%
      y  = 1 - elv/90.0;
      x  = y.*y;
%
      c4=  -4.78959020184645;
      c3=   7.19173702655717;
      c2=  -1.75874288121271;
      c1=   1.43253443767944;
      c0=   0.99357343653120;
%
      sum = c4;
      sum = c3 + sum.*x;
      sum = c2 + sum.*x;
      sum = c1 + sum.*x;
      sum = c0 + sum.*x;
%
      q   = sum;
%
      return;
